#[non_exhaustive]pub enum WireTxErrorKind {
ConnectionClosed,
Other,
Timeout,
}Expand description
The base WireTx Error Kind
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ConnectionClosed
The connection has been closed, and is unlikely to succeed until the connection is re-established. This will cause the Server run loop to terminate.
Other
Other unspecified errors
Timeout
Timeout (WireTx impl specific) reached